Module config

Module config 

A module to corral configuration to the side and into a single source of truth. Provides conveniences for answering config questions without having to pass batons around.

Structs

ConfigOpts
A sensible holder for our configuration.

Enums

InputMode
Operation modes for tale
OffsetUnit

Functions

batch_window_ms
config
Get reference to configuration
conservative
disable_chunked
force_chunked
mode
offset
offset_unit
set
Set configuration - one-time initialization only
show_time
sticky
tailing