Args

Struct Args 

pub struct Args {
Show 17 fields pub follow: bool, pub sticky: bool, pub blocks: Option<i64>, pub bytes: Option<i64>, pub offset: Option<i64>, pub verbose: bool, pub quiet: bool, pub timestamps: bool, pub window: u64, pub chunked: bool, pub no_chunked: bool, pub adaptive: bool, pub max_memory: Option<usize>, pub conservative: bool, pub chunk_strategy: Option<Strategy>, pub profile_json: bool, pub args: Vec<String>,
}
A tail-compatible tool for pretty-printing ndjson files, especially logs.

Tale displays the colorfully-formatted contents of FILE, by default stdin, to stdout. It highlights the fields likely to appear in log lines for servers, such as level or severity, the log message, timestamps, and so on. It also displays every field that shows up in the log line, using the color theme you have set in your terminal.

Lines that are invalid json are printed intact, without formatting.

Tale can also follow and display more than one file at a time, with header decoration options like tail’s.

Fields

follow: bool

Follow the file, continuing to watch for more data to arrive.

sticky: bool

Follow the file, also checking to see if has been renamed or has an new inode number. If the file does not exist yet, wait and display it from the beginning if and when it is created.

blocks: Option<i64>

Start tailing the input offset by ±N blocks.

bytes: Option<i64>

Start tailing the input offset by ±N bytes; e.g., to skip garbage.

offset: Option<i64>

Start tailing the input offset by ±N lines.

verbose: bool

When following more than one file, show a header with the file name along with every line from that file.

quiet: bool

Do not ever show file name headers when following more than one file.

timestamps: bool

Show timestamps, which are hidden by default.

window: u64

Batch window size for multi-file tailing (in milliseconds).

chunked: bool

Force use of chunked file processing for better memory efficiency on large files.

no_chunked: bool

Disable chunked file processing and always use streaming (might use more memory).

adaptive: bool

Disable adaptive chunking

max_memory: Option<usize>

Set a limit on how much memory can be used in file buffers

conservative: boolchunk_strategy: Option<Strategy>

Choose a specific chunk strategy for testing

profile_json: bool

Print JSON parsing profile report after processing (debug builds only)

args: Vec<String>

(offset) [file …] where offset can be +N, -N, or N.