JSON log patterns and deserialization implementations, plus pretty-printing for all identified varieties. Also, traits for all of them, so everything outside this module doesn’t have to care what kind of log pattern it is: its just a printable log.
Structs
- Sourced
Line - A wrapper that combines a parsed log line with source file metadata. This is used for multi-file processing to track which file each line came from.
Enums
- Printable
- An enum to help serde deserialize incoming log lines. There are some we decide are log lines with fields we recognize, and some that are just json we pretty-print. And then there’s plain text. Ordered from most specific to least specific for serde deserialization.
Traits
- Pretty
Printable - If you can be pretty-printed, you write into a mutable byte buffer. We don’t have any opinions about what you write; pretty is in the eye of the implementor.